@@ -1,5 +1,5 @@
 from fastapi_controllers.controllers import Controller
-from fastapi_controllers.routing import delete, get, head, options, patch, post, put, trace
+from fastapi_controllers.routing import delete, get, head, options, patch, post, put, trace, websocket
 
 __all__ = [
     "Controller",
@@ -11,4 +11,5 @@ __all__ = [
     "post",
     "put",
     "trace",
+    "websocket",
 ]
